@@ -22,6 +22,7 @@
 import logging
 import os
 import re
+import locale
 from datetime import datetime
 from glob import glob
 from pickle import dumps
@@ -42,7 +43,7 @@ def relpath(target, link):
     """
     t = target.split('/')
     l = link.split('/')
-    while l[0] == t[0]:
+    while l and l[0] == t[0]:
         del l[0], t[0]
     return '/'.join(['..'] * (len(l) - 1) + t)
 
@@ -67,18 +68,26 @@ def move_file(fpath, dstdir):
         os.rename(fpath, dstdir)
 
 
-def move_matching_files(src, dst, pattern):
+def move_matching_files(src, dst, pattern, sub=None, repl=''):
     """Move files (preserving path) that match given pattern.
 
-    move_files('foo/bar/', 'foo/baz/', 'spam/.*\.so$')
+    move_matching_files('foo/bar/', 'foo/baz/', 'spam/.*\.so$')
     will move foo/bar/a/b/c/spam/file.so to foo/baz/a/b/c/spam/file.so
+
+    :param sub: regular expression for path part that will be replaced with `repl`
+    :param repl: replacement for `sub`
     """
     match = re.compile(pattern).search
+    if sub:
+        sub = re.compile(sub).sub
+        repl = repl or ''
     for root, dirs, filenames in os.walk(src):
         for fn in filenames:
             spath = join(root, fn)
             if match(spath):
-                dpath = join(dst, spath.lstrip(src).lstrip('/'))
+                if sub is not None:
+                    spath = sub(repl, spath)
+                dpath = join(dst, relpath(spath, src))
                 os.renames(spath, dpath)
 
 
@@ -93,7 +102,12 @@ def fix_shebang(fpath, replacement=None):
         log.debug('fix_shebang (%s): %s', fpath, err)
         return None
 
-    if not replacement and interpreter.path != '/usr/bin/':  # f.e. /usr/local/* or */bin/env
+    if not replacement and interpreter.version == '2':
+        # we'll drop /usr/bin/python symlink from python package at some point
+        replacement = '/usr/bin/python2'
+        if interpreter.debug:
+            replacement += '-dbg'
+    elif not replacement and interpreter.path != '/usr/bin/':  # f.e. /usr/local/* or */bin/env
         interpreter.path = '/usr/bin'
         replacement = repr(interpreter)
     if replacement:
@@ -121,7 +135,8 @@ def so2pyver(fpath):
 
     cmd = "readelf -Wd '%s'" % fpath
     process = Popen(cmd, stdout=PIPE, shell=True)
-    match = SHAREDLIB_RE.search(str(process.stdout.read(), encoding='utf-8'))
+    encoding = locale.getdefaultlocale()[1] or 'utf-8'
+    match = SHAREDLIB_RE.search(str(process.stdout.read(), encoding=encoding))
     if match:
         return Version(match.groups()[0])
 
@@ -189,7 +204,7 @@ def remove_ns(interpreter, package, namespaces, versions):
     return result
 
 
-def execute(command, cwd=None, env=None, log_output=None):
+def execute(command, cwd=None, env=None, log_output=None, shell=True):
     """Execute external shell commad.
 
     :param cdw: currennt working directory
@@ -199,7 +214,7 @@ def execute(command, cwd=None, env=None, log_output=None):
         * None if output should be included in the returned dict, or
         * False if output should be redirectored to stdout/stderr
     """
-    args = {'shell': True, 'cwd': cwd, 'env': env}
+    args = {'shell': shell, 'cwd': cwd, 'env': env}
     close = False
     if log_output is False:
         pass
@@ -301,7 +316,7 @@ def pyremove(interpreter, package, vrange):
             site_dirs = interpreter.old_sitedirs(package, version)
             site_dirs.append(interpreter.sitedir(package, version))
             for sdir in site_dirs:
-                files = glob(sdir + details['pattern'])
+                files = glob(sdir + '/' + details['pattern'])
                 for fpath in files:
                     if isdir(fpath):
                         rmtree(fpath)
